ete2.treeview._show_newick

Package ete2 :: Package treeview :: Module _show_newick |
[hide private]
[frames] | no frames]

# Source Code for Module ete2.treeview._show_newick

      1  # #START_LICENSE###########################################################
      2  #
      3  # Copyright (C) 2009 by Jaime Huerta Cepas. All rights reserved.
      4  # email: jhcepas@gmail.com
      5  #
      6  # This file is part of the Environment for Tree Exploration program (ETE).
      7  # http://ete.cgenomics.org
      8  #
      9  # ETE is free software: you can redistribute it and/or modify it
     10  # under the terms of the GNU General Public License as published by
     11  # the Free Software Foundation, either version 3 of the License, or
     12  # (at your option) any later version.
     13  #
     14  # ETE is distributed in the hope that it will be useful,
     15  # but WITHOUT ANY WARRANTY; without even the implied warranty of
     16  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     17  # GNU General Public License for more details.
     18  #
     19  # You should have received a copy of the GNU General Public License
     20  # along with ETE.  If not, see <http://www.gnu.org/licenses/>.
     21  #
     22  # #END_LICENSE#############################################################
     23  __VERSION__="ete2-2.0rev90"
     24  # -*- coding: utf-8 -*-
     25
     26  # Form implementation generated from reading ui file 'show_newick.ui'
     27  #
     28  # Created: Mon Sep 14 11:11:49 2009
     29  #      by: PyQt4 UI code generator 4.5.4
     30  #
     31  # WARNING! All changes made in this file will be lost!
     32
     33  try:
     34      from PyQt4 import QtCore, QtGui
     35  except ImportError:
     36      import QtCore, QtGui
     37
     38
     39 -class Ui_Newick(object):
     40 -    def setupUi(self, Newick):
     41          Newick.setObjectName("Newick")
     42          Newick.resize(594, 397)
     43          self.nwFormat = QtGui.QComboBox(Newick)
     44          self.nwFormat.setGeometry(QtCore.QRect(200, 20, 51, 23))
     45          self.nwFormat.setObjectName("nwFormat")
     46          self.nwFormat.addItem(QtCore.QString())
     47          self.nwFormat.addItem(QtCore.QString())
     48          self.nwFormat.addItem(QtCore.QString())
     49          self.nwFormat.addItem(QtCore.QString())
     50          self.nwFormat.addItem(QtCore.QString())
     51          self.nwFormat.addItem(QtCore.QString())
     52          self.nwFormat.addItem(QtCore.QString())
     53          self.nwFormat.addItem(QtCore.QString())
     54          self.nwFormat.addItem(QtCore.QString())
     55          self.nwFormat.addItem(QtCore.QString())
     56          self.nwFormat.addItem(QtCore.QString())
     57          self.label = QtGui.QLabel(Newick)
     58          self.label.setGeometry(QtCore.QRect(100, 20, 91, 20))
     59          self.label.setObjectName("label")
     60          self.verticalLayoutWidget = QtGui.QWidget(Newick)
     61          self.verticalLayoutWidget.setGeometry(QtCore.QRect(300, 10, 258, 361))
     62          self.verticalLayoutWidget.setObjectName("verticalLayoutWidget")
     63          self.verticalLayout = QtGui.QVBoxLayout(self.verticalLayoutWidget)
     64          self.verticalLayout.setObjectName("verticalLayout")
     65          self.newickBox = QtGui.QTextEdit(self.verticalLayoutWidget)
     66          self.newickBox.setObjectName("newickBox")
     67          self.verticalLayout.addWidget(self.newickBox)
     68          self.attrName = QtGui.QLineEdit(Newick)
     69          self.attrName.setGeometry(QtCore.QRect(20, 80, 113, 25))
     70          self.attrName.setObjectName("attrName")
     71          self.pushButton = QtGui.QPushButton(Newick)
     72          self.pushButton.setGeometry(QtCore.QRect(140, 80, 51, 29))
     73          self.pushButton.setObjectName("pushButton")
     74          self.pushButton_2 = QtGui.QPushButton(Newick)
     75          self.pushButton_2.setGeometry(QtCore.QRect(200, 80, 51, 29))
     76          self.pushButton_2.setObjectName("pushButton_2")
     77          self.features_list = QtGui.QListWidget(Newick)
     78          self.features_list.setGeometry(QtCore.QRect(20, 120, 231, 251))
     79          self.features_list.setObjectName("features_list")
     80          self.label_3 = QtGui.QLabel(Newick)
     81          self.label_3.setGeometry(QtCore.QRect(60, 60, 191, 20))
     82          self.label_3.setObjectName("label_3")
     83          self.useAllFeatures = QtGui.QCheckBox(Newick)
     84          self.useAllFeatures.setGeometry(QtCore.QRect(20, 370, 221, 24))
     85          self.useAllFeatures.setObjectName("useAllFeatures")
     86
     87          self.retranslateUi(Newick)
     88          QtCore.QObject.connect(self.nwFormat, QtCore.SIGNAL("activated(QString)"), Newick.update_newick)
     89          QtCore.QObject.connect(self.pushButton, QtCore.SIGNAL("released()"), Newick.add_feature)
     90          QtCore.QObject.connect(self.pushButton_2, QtCore.SIGNAL("released()"), Newick.del_feature)
     91          QtCore.QObject.connect(self.useAllFeatures, QtCore.SIGNAL("released()"), Newick.set_custom_features)
     92          QtCore.QMetaObject.connectSlotsByName(Newick)
     93
     94 -    def retranslateUi(self, Newick):
     95          Newick.setWindowTitle(QtGui.QApplication.translate("Newick", "Dialog", None, QtGui.QApplication.UnicodeUTF8))
     96          self.nwFormat.setItemText(0, QtGui.QApplication.translate("Newick", "0", None, QtGui.QApplication.UnicodeUTF8))
     97          self.nwFormat.setItemText(1, QtGui.QApplication.translate("Newick", "1", None, QtGui.QApplication.UnicodeUTF8))
     98          self.nwFormat.setItemText(2, QtGui.QApplication.translate("Newick", "2", None, QtGui.QApplication.UnicodeUTF8))
     99          self.nwFormat.setItemText(3, QtGui.QApplication.translate("Newick", "3", None, QtGui.QApplication.UnicodeUTF8))
    100          self.nwFormat.setItemText(4, QtGui.QApplication.translate("Newick", "4", None, QtGui.QApplication.UnicodeUTF8))
    101          self.nwFormat.setItemText(5, QtGui.QApplication.translate("Newick", "5", None, QtGui.QApplication.UnicodeUTF8))
    102          self.nwFormat.setItemText(6, QtGui.QApplication.translate("Newick", "6", None, QtGui.QApplication.UnicodeUTF8))
    103          self.nwFormat.setItemText(7, QtGui.QApplication.translate("Newick", "7", None, QtGui.QApplication.UnicodeUTF8))
    104          self.nwFormat.setItemText(8, QtGui.QApplication.translate("Newick", "8", None, QtGui.QApplication.UnicodeUTF8))
    105          self.nwFormat.setItemText(9, QtGui.QApplication.translate("Newick", "9", None, QtGui.QApplication.UnicodeUTF8))
    106          self.nwFormat.setItemText(10, QtGui.QApplication.translate("Newick", "100", None, QtGui.QApplication.UnicodeUTF8))
    107          self.label.setText(QtGui.QApplication.translate("Newick", "Newick format", None, QtGui.QApplication.UnicodeUTF8))
    108          self.pushButton.setText(QtGui.QApplication.translate("Newick", "Add", None, QtGui.QApplication.UnicodeUTF8))
    109          self.pushButton_2.setText(QtGui.QApplication.translate("Newick", "Del", None, QtGui.QApplication.UnicodeUTF8))
    110          self.label_3.setText(QtGui.QApplication.translate("Newick", "Node\'s attribute (NHX format)", None, QtGui.QApplication.UnicodeUTF8))
    111          self.useAllFeatures.setText(QtGui.QApplication.translate("Newick", "Include all attributes in nodes", None, QtGui.QApplication.UnicodeUTF8))
    112